@@ -63,7 +63,7 @@ def retrieve_profile(profile_name):
 
     # Look for the required profile
     if section_name not in config:
-        sys.exit("Cannot find profile '%s' in ~/.aws/config" % profile_name)
+        sys.exit("Cannot find profile '%s' in %s" % (profile_name, config_path))
     # Retrieve the values as dict
     profile = dict(config[section_name])
 
@@ -149,7 +149,7 @@ def get_role_credentials(profile):
 
     output = json.loads(result.stdout)
     # convert expiration from float value to isoformat string
-    output["roleCredentials"]["expiration"] = datetime.fromtimestamp(float(output["roleCredentials"]["expiration"])/1000).replace(tzinfo=timezone.utc).isoformat()
+    output["roleCredentials"]["expiration"] = datetime.fromtimestamp(float(output["roleCredentials"]["expiration"])/1000, tz=timezone.utc).isoformat()
     return output
 
 
@@ -212,6 +212,9 @@ def process_cred_generation(
     access_key, secret_access_key, session_token, profile):
     """ Export the credentials and config """
 
+    credentialsfile = os.path.expanduser(credentialsfile) 
+    configfile = os.path.expanduser(configfile) 
+
     config = configparser.ConfigParser()
     config.read(credentialsfile)
     config[outprofile] = {
@@ -222,6 +225,7 @@ def process_cred_generation(
     with open(credentialsfile, "w") as file:
         config.write(file)
 
+    config = configparser.ConfigParser()
     config.read(configfile)
     new_config = {}
     if "region" in profile:
@@ -319,7 +323,7 @@ def main():
             "AccessKeyId": access_key,
             "SecretAccessKey": secret_access_key,
             "SessionToken": session_token,
-            "Expiration": expiration,
+            "Expiration": expiration.replace('+00:00', 'Z'),
         }
         print(json.dumps(output))
     else:
